<?php

/**
 * @file
 * Administration form.
 */

/**
 * Module configuration form.
 */
function adverticum_admin_settings(&$form_state) {
  $form['adverticum_tag_global'] = array(
    '#type'           => 'radios',
    '#title'          => t('Global tag setting'),
    '#description'    => t('If set, the tag setting for a zone will be ignored and all zones will be displayed using this tag.'),
    '#attributes'     => array('class' => 'tag-global'),
    '#default_value' => variable_get('adverticum_tag_global', 'none'),
    '#options' => array(
      'none'  => t('None'),
      'goa3'  => t('Goa3'),
      'js'    => t('JavaScript')
     ),
     '#weight' => -1,
  );

  $form['blocks'] = array(
    '#title'        => t('Adverticum blocks'),
    '#type'         => 'fieldset',
    '#description'  => t('The zone ID can be found in the Adverticum administration interface. 
      The name can be any alpha-numeric string, this will be used for the block name.
      Note that some type of banner appereances (Layer) are supported by the Goa3 tag only.'),
  );

  $form['blocks']['adverticum_zones'] = array(
    '#tree'             => TRUE,
    '#theme'            => 'adverticum_admin_settings_zones',
    '#element_validate' => array('adverticum_admin_settings_zones_validate'),
  );

  $form_state['storage']['zones'] = isset($form_state['storage']['zones']) ? $form_state['storage']['zones'] : variable_get('adverticum_zones', array_fill(0, 3, array('id' => '', 'name' => '', 'tag' => '', 'status' => '')));
  if (empty($form_state['storage']['zones'])) {
    $form_state['storage']['zones'] = array_fill(0, 3, array('id' => '', 'name' => '', 'tag' => '', 'status' => ''));
  }

  foreach ($form_state['storage']['zones'] as $id => $zone) {
    $form['blocks']['adverticum_zones'][$id]['id'] = array(
      '#type'           => 'textfield',
      '#default_value'  => isset($form_state['values']['adverticum_zones'][$id]['id']) ? $form_state['values']['adverticum_zones'][$id]['id'] : $form_state['storage']['zones'][$id]['id'],
      '#size'           => 6,
      '#attributes'     => array('class' => 'zone-id'),
    );
    $form['blocks']['adverticum_zones'][$id]['name'] = array(
      '#type'           => 'textfield',
      '#default_value'  => isset($form_state['values']['adverticum_zones'][$id]['name']) ? $form_state['values']['adverticum_zones'][$id]['name'] : $form_state['storage']['zones'][$id]['name'],
      '#size'           => 64,
      '#attributes'     => array('class' => 'zone-name'),
    );
    $form['blocks']['adverticum_zones'][$id]['tag'] = array(
      '#type' => 'radios',
      '#default_value' => isset($form_state['values']['adverticum_zones'][$id]['tag']) ? $form_state['values']['adverticum_zones'][$id]['tag'] : $form_state['storage']['zones'][$id]['tag'],
      '#options' => array(
        'goa3' => t('Goa3'),
        'js' => t('JavaScript'),
      ),
    );
    $form['blocks']['adverticum_zones'][$id]['status'] = array(
      '#type' => 'checkbox',
      '#default_value' => isset($form_state['values']['adverticum_zones'][$id]['status']) ? $form_state['values']['adverticum_zones'][$id]['status'] : $form_state['storage']['zones'][$id]['status'],
    );
    $form['blocks']['adverticum_zones'][$id]['delete'] = array(
      '#type' => 'submit',
      '#value' => t('delete'),
      '#submit' => array('adverticum_admin_settings_del_zone'),
      '#name' => 'adverticum-zones-delete-' . $id,
      '#key' => $id,
      '#disabled' => (count($form_state['storage']['zones']) == 1),
    );
  }

  $form['blocks']['add_zone'] = array(
    '#type' => 'submit',
    '#value' => t('Add zone'),
    '#submit' => array('adverticum_admin_settings_add_zone'),
  );

  $form['#submit'] = array('adverticum_admin_settings_submit');
  return system_settings_form($form);
}

/**
 * Handles form submit.
 */
function adverticum_admin_settings_submit(&$form, &$form_state) {
  unset($form_state['storage']);
}

/**
 * Handles form submit with the 'Add zone' button.
 */
function adverticum_admin_settings_add_zone(&$form, &$form_state) {
  $form_state['storage']['zones'] = $form_state['values']['adverticum_zones'];
  $form_state['storage']['zones'][] = array('id' => '', 'name' => '', 'tag' => NULL, 'status' => 0);
  $form_state['rebuild'] = TRUE;
}

/**
 * Handles form submit with the 'Delete' button.
 */
function adverticum_admin_settings_del_zone(&$form, &$form_state) {
  $form_state['storage']['zones'] = $form_state['values']['adverticum_zones'];
  unset($form_state['storage']['zones'][$form_state['clicked_button']['#key']]);
  $form_state['rebuild'] = TRUE;
}

/**
 * Handles form validation.
 */
function adverticum_admin_settings_zones_validate(&$form, &$form_state) {
  $errors = FALSE;

  if (isset($form_state['clicked_button']['#submit'])) {
    return;
  }

  $zones = $form_state['values']['adverticum_zones'];
  foreach ($zones as $index => $zone) {
    if (empty($zone['id']) && empty($zone['name'])) {
      unset($zones[$index]);
    }
    elseif (empty($zone['id'])) {
      $errors = TRUE;
      form_error($form[$index]['id'], t('Zone ID field is required.'));
    }
    elseif (empty($zone['tag'])) {
      $errors = TRUE;
      form_error($form[$index]['tag'], t('You need to choose a tag type for the zone.'));
    }
  }

  if (!$errors) {
    form_set_value($form, $zones, $form_state);
  }
}
